jactorch.functional
===================

.. automodule:: jactorch.functional

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Submodules
.. autosummary::
   :toctree:
   :template: base.rst
   :recursive:

   arith
   clustering
   grad
   indexing
   kernel
   linalg
   loglinear
   masking
   probability
   quantization
   range
   sampling
   shape









